// LabPlot : spreadsheetProperties.h

#ifndef SPREASHEETPROPERTIES_H
#define SPREASHEETPROPERTIES_H

#include "formatlist.h"

#define NR_COLUMNTYPES 8
static const char* columnTypeItems[] = {"[X]","[Y]","[Z]","[DX]","[DY]","[DY2]","[LABEL]","[NONE]",0};

#endif // SPREASHEETPROPERTIES_H
